@@ -58,9 +58,8 @@ sub method {
           } else {
               return $response;
           }
-
         } else {
-          confess('Response Content-Type header missing')
+          return $response;
         }
     }
 }
@@ -80,7 +79,7 @@ REST::Cot::Generators
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 AUTHOR
 
